@@ -31,6 +31,12 @@ class GithubRepository(Repository):
             url=self.repo.clone_url, password=self.access_token
         )
 
+    def close_pull_request(
+        self, message: str, pr: github.PullRequest.PullRequest
+    ) -> None:
+        pr.create_issue_comment(body=message)
+        pr.edit(state="closed")
+
     def create_pull_request(self, branch: str, pr: PullRequest):
         log.debug(
             "Creating pull request", base=self.base_branch, head=branch, repo=str(self)
@@ -122,6 +128,20 @@ class GithubRepository(Repository):
     def source(self) -> str:
         return "github.com"
 
+    def update_pull_request(
+        self, pr: github.PullRequest.PullRequest, pr_data: PullRequest
+    ) -> None:
+        needs_update = False
+        if pr.title != pr_data.title:
+            needs_update = True
+
+        if pr.body != pr_data.body:
+            needs_update = True
+
+        if needs_update is True:
+            log.debug("Updating PR data", pr_id=pr.id, repo=str(self))
+            pr.edit(title=pr_data.title, body=pr_data.body)
+
 
 class Github(Base):
     def __init__(self, access_token: str, base_url: str):
